Class: Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb

Overview

REST client for the CloudProductRegistryReadService service.

Cloud Product Registry Read Service provides capabilities to access all first and third party Google Cloud products.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#logical_product_path, #logical_product_variant_path, #product_suite_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new CloudProductRegistryReadService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the CloudProductRegistryReadService client.

Yield Parameters:



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 162

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @cloud_product_registry_read_service_stub = ::Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @cloud_product_registry_read_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the CloudProductRegistryReadService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all CloudProductRegistryReadService clients
::Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 65

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "ProductRegistry", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.get_product_suite.timeout = 60.0
    default_config.rpcs.get_product_suite.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_product_suites.timeout = 60.0
    default_config.rpcs.list_product_suites.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_logical_product.timeout = 60.0
    default_config.rpcs.get_logical_product.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_logical_products.timeout = 60.0
    default_config.rpcs.list_logical_products.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_logical_product_variant.timeout = 60.0
    default_config.rpcs.get_logical_product_variant.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_logical_product_variants.timeout = 60.0
    default_config.rpcs.list_logical_product_variants.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.lookup_entity.timeout = 60.0
    default_config.rpcs.lookup_entity.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the CloudProductRegistryReadService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



132
133
134
135
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 132

def configure
  yield @config if block_given?
  @config
end

#get_logical_product(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProduct #get_logical_product(name: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProduct

Gets details of a LogicalProduct.

Examples:

Basic example

require "google/cloud/product_registry/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ProductRegistry::V1::GetLogicalProductRequest.new

# Call the get_logical_product method.
result = client.get_logical_product request

# The returned object is of type Google::Cloud::ProductRegistry::V1::LogicalProduct.
p result

Overloads:

  • #get_logical_product(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProduct

    Pass arguments to get_logical_product via a request object, either of type GetLogicalProductRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ProductRegistry::V1::GetLogicalProductRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_logical_product(name: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProduct

    Pass arguments to get_logical_product via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the LogicalProduct to retrieve. Format: logicalProducts/{logical_product}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 430

def get_logical_product request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::GetLogicalProductRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_logical_product..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_logical_product.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_logical_product.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_product_registry_read_service_stub.get_logical_product request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_logical_product_variant(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProductVariant #get_logical_product_variant(name: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProductVariant

Get details of a LogicalProductVariant.

Examples:

Basic example

require "google/cloud/product_registry/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ProductRegistry::V1::GetLogicalProductVariantRequest.new

# Call the get_logical_product_variant method.
result = client.get_logical_product_variant request

# The returned object is of type Google::Cloud::ProductRegistry::V1::LogicalProductVariant.
p result

Overloads:

  • #get_logical_product_variant(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProductVariant

    Pass arguments to get_logical_product_variant via a request object, either of type GetLogicalProductVariantRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ProductRegistry::V1::GetLogicalProductVariantRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_logical_product_variant(name: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProductVariant

    Pass arguments to get_logical_product_variant via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the LogicalProductVariant to retrieve. Format: logicalProducts/{logical_product}/variants/{variant}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 606

def get_logical_product_variant request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::GetLogicalProductVariantRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_logical_product_variant..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_logical_product_variant.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_logical_product_variant.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_product_registry_read_service_stub.get_logical_product_variant request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_product_suite(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::ProductSuite #get_product_suite(name: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::ProductSuite

Get details of a ProductSuite.

Examples:

Basic example

require "google/cloud/product_registry/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ProductRegistry::V1::GetProductSuiteRequest.new

# Call the get_product_suite method.
result = client.get_product_suite request

# The returned object is of type Google::Cloud::ProductRegistry::V1::ProductSuite.
p result

Overloads:

  • #get_product_suite(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::ProductSuite

    Pass arguments to get_product_suite via a request object, either of type GetProductSuiteRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ProductRegistry::V1::GetProductSuiteRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_product_suite(name: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::ProductSuite

    Pass arguments to get_product_suite via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the ProductSuite to retrieve. Format: productSuites/{product_suite}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 259

def get_product_suite request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::GetProductSuiteRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_product_suite..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_product_suite.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_product_suite.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_product_registry_read_service_stub.get_product_suite request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_logical_product_variants(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProductVariant> #list_logical_product_variants(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProductVariant>

Lists LogicalProductVariants matching given criteria.

Examples:

Basic example

require "google/cloud/product_registry/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ProductRegistry::V1::ListLogicalProductVariantsRequest.new

# Call the list_logical_product_variants method.
result = client.list_logical_product_variants request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::ProductRegistry::V1::LogicalProductVariant.
  p item
end

Overloads:

  • #list_logical_product_variants(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProductVariant>

    Pass arguments to list_logical_product_variants via a request object, either of type ListLogicalProductVariantsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ProductRegistry::V1::ListLogicalProductVariantsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_logical_product_variants(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProductVariant>

    Pass arguments to list_logical_product_variants via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Parent logical product id. Format: logicalProducts/{logical_product}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of logical product variants to return. The service may return fewer than this value. If unspecified, at most 100 logical product variants will be returned. The maximum value is 500; values above 500 will be coerced to 500.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListLogicalProductVariants call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListLogicalProductVariants must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 702

def list_logical_product_variants request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::ListLogicalProductVariantsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_logical_product_variants..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_logical_product_variants.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_logical_product_variants.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_product_registry_read_service_stub.list_logical_product_variants request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @cloud_product_registry_read_service_stub, :list_logical_product_variants, "logical_product_variants", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_logical_products(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProduct> #list_logical_products(filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProduct>

Lists LogicalProducts matching given criteria.

Examples:

Basic example

require "google/cloud/product_registry/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ProductRegistry::V1::ListLogicalProductsRequest.new

# Call the list_logical_products method.
result = client.list_logical_products request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::ProductRegistry::V1::LogicalProduct.
  p item
end

Overloads:

  • #list_logical_products(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProduct>

    Pass arguments to list_logical_products via a request object, either of type ListLogicalProductsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ProductRegistry::V1::ListLogicalProductsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_logical_products(filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProduct>

    Pass arguments to list_logical_products via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • filter (::String) (defaults to: nil)

      Optional. The filter expression for listing logical products. Filter syntax: https://google.aip.dev/160 Supported fields: suite_id

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of logical products to return. The service may return fewer than this value. If unspecified, at most 100 logical products will be returned. The maximum value is 500; values above 500 will be coerced to 500.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListLogicalProducts call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListLogicalProducts must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 525

def list_logical_products request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::ListLogicalProductsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_logical_products..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_logical_products.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_logical_products.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_product_registry_read_service_stub.list_logical_products request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @cloud_product_registry_read_service_stub, :list_logical_products, "logical_products", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_product_suites(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::ProductSuite> #list_product_suites(page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::ProductSuite>

Lists ProductSuites.

Examples:

Basic example

require "google/cloud/product_registry/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ProductRegistry::V1::ListProductSuitesRequest.new

# Call the list_product_suites method.
result = client.list_product_suites request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::ProductRegistry::V1::ProductSuite.
  p item
end

Overloads:

  • #list_product_suites(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::ProductSuite>

    Pass arguments to list_product_suites via a request object, either of type ListProductSuitesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ProductRegistry::V1::ListProductSuitesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_product_suites(page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::ProductSuite>

    Pass arguments to list_product_suites via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of suites to return. The service may return fewer than this value. If unspecified, at most 100 suites will be returned. The maximum value is 500; values above 500 will be coerced to 500.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListProductSuites call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListProductSuites must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 349

def list_product_suites request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::ListProductSuitesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_product_suites..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_product_suites.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_product_suites.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_product_registry_read_service_stub.list_product_suites request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @cloud_product_registry_read_service_stub, :list_product_suites, "product_suites", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


209
210
211
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 209

def logger
  @cloud_product_registry_read_service_stub.logger
end

#lookup_entity(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LookupEntityResponse #lookup_entity(lookup_uri: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LookupEntityResponse

Look up entities.

Examples:

Basic example

require "google/cloud/product_registry/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::ProductRegistry::V1::LookupEntityRequest.new

# Call the lookup_entity method.
result = client.lookup_entity request

# The returned object is of type Google::Cloud::ProductRegistry::V1::LookupEntityResponse.
p result

Overloads:

  • #lookup_entity(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LookupEntityResponse

    Pass arguments to lookup_entity via a request object, either of type LookupEntityRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::ProductRegistry::V1::LookupEntityRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #lookup_entity(lookup_uri: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LookupEntityResponse

    Pass arguments to lookup_entity via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • lookup_uri (::String) (defaults to: nil)

      Required. Entity uri to look up. Supported Formats: logicalProducts/{logical_product} logicalProducts/{logical_product}/variants/{variant} productSuites/{product_suite}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 786

def lookup_entity request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::LookupEntityRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.lookup_entity..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.lookup_entity.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.lookup_entity.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_product_registry_read_service_stub.lookup_entity request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


142
143
144
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/rest/client.rb', line 142

def universe_domain
  @cloud_product_registry_read_service_stub.universe_domain
end