Class: Google::Cloud::ProductRegistry::V1::ListLogicalProductVariantsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb

Overview

Response message for ListLogicalProductVariants.

Instance Attribute Summary collapse

Instance Attribute Details

#logical_product_variants::Array<::Google::Cloud::ProductRegistry::V1::LogicalProductVariant>

Returns Matched LogicalProductVariants.

Returns:



155
156
157
158
# File 'proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb', line 155

class ListLogicalProductVariantsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



155
156
157
158
# File 'proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb', line 155

class ListLogicalProductVariantsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end