Class: Google::Cloud::ProductRegistry::V1::LogicalProductVariant

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/productregistry/v1/logical_product_variant.rb

Overview

Represents a distinct offering derived from a primary product that retains core functionalities but offers specialized features for a specific market segment.

Instance Attribute Summary collapse

Instance Attribute Details

#lifecycle_state::Google::Cloud::ProductRegistry::V1::LifecycleState (readonly)

Returns Output only. Current Lifecycle state of the logical product variant.

Returns:



50
51
52
53
# File 'proto_docs/google/cloud/productregistry/v1/logical_product_variant.rb', line 50

class LogicalProductVariant
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the LogicalProductVariant. Format: logicalProducts/{logical_product}/variants/{variant}.

Returns:

  • (::String)

    Identifier. The resource name of the LogicalProductVariant. Format: logicalProducts/{logical_product}/variants/{variant}



50
51
52
53
# File 'proto_docs/google/cloud/productregistry/v1/logical_product_variant.rb', line 50

class LogicalProductVariant
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#replaced::Boolean (readonly)

Returns Output only. Indicates whether the logical product variant has been replaced. If false, the variant is active. If true, the variant has been replaced by another type, and the replacement field contains the resource name of that replacement.

Returns:

  • (::Boolean)

    Output only. Indicates whether the logical product variant has been replaced. If false, the variant is active. If true, the variant has been replaced by another type, and the replacement field contains the resource name of that replacement.



50
51
52
53
# File 'proto_docs/google/cloud/productregistry/v1/logical_product_variant.rb', line 50

class LogicalProductVariant
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#replacement::String (readonly)

Returns Output only. The resource name of the Logical Entity that the logical product variant is replaced by. This field is only populated when this logical product variant is replaced by some other type. Eg: logicalProducts/{logical_product}, productSuites/{product_suite}, etc.

Returns:

  • (::String)

    Output only. The resource name of the Logical Entity that the logical product variant is replaced by. This field is only populated when this logical product variant is replaced by some other type. Eg: logicalProducts/{logical_product}, productSuites/{product_suite}, etc.



50
51
52
53
# File 'proto_docs/google/cloud/productregistry/v1/logical_product_variant.rb', line 50

class LogicalProductVariant
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#title::String

Returns Display name of the LogicalProductVariant.

Returns:

  • (::String)

    Display name of the LogicalProductVariant.



50
51
52
53
# File 'proto_docs/google/cloud/productregistry/v1/logical_product_variant.rb', line 50

class LogicalProductVariant
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end