Class: Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb
Overview
Client for the CloudProductRegistryReadService service.
Cloud Product Registry Read Service provides capabilities to access all first and third party Google Cloud products.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the CloudProductRegistryReadService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the CloudProductRegistryReadService Client instance.
-
#get_logical_product(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProduct
Gets details of a LogicalProduct.
-
#get_logical_product_variant(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProductVariant
Get details of a LogicalProductVariant.
-
#get_product_suite(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::ProductRegistry::V1::ProductSuite
Get details of a ProductSuite.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new CloudProductRegistryReadService client object.
-
#list_logical_product_variants(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProductVariant>
Lists LogicalProductVariants matching given criteria.
-
#list_logical_products(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProduct>
Lists LogicalProducts matching given criteria.
-
#list_product_suites(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::ProductSuite>
Lists ProductSuites.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#lookup_entity(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::ProductRegistry::V1::LookupEntityResponse
Look up entities.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#logical_product_path, #logical_product_variant_path, #product_suite_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new CloudProductRegistryReadService client object.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 160 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/productregistry/v1/cloud_product_registry_read_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @cloud_product_registry_read_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::ProductRegistry::V1::CloudProductRegistryReadService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @cloud_product_registry_read_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the CloudProductRegistryReadService Client class.
See Configuration for a description of the configuration fields.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 63 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "ProductRegistry", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.get_product_suite.timeout = 60.0 default_config.rpcs.get_product_suite.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_product_suites.timeout = 60.0 default_config.rpcs.list_product_suites.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_logical_product.timeout = 60.0 default_config.rpcs.get_logical_product.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_logical_products.timeout = 60.0 default_config.rpcs.list_logical_products.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_logical_product_variant.timeout = 60.0 default_config.rpcs.get_logical_product_variant.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_logical_product_variants.timeout = 60.0 default_config.rpcs.list_logical_product_variants.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.lookup_entity.timeout = 60.0 default_config.rpcs.lookup_entity.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the CloudProductRegistryReadService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
130 131 132 133 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 130 def configure yield @config if block_given? @config end |
#get_logical_product(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProduct #get_logical_product(name: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProduct
Gets details of a LogicalProduct.
444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 444 def get_logical_product request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::GetLogicalProductRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_logical_product..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_logical_product.timeout, metadata: , retry_policy: @config.rpcs.get_logical_product.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @cloud_product_registry_read_service_stub.call_rpc :get_logical_product, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_logical_product_variant(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProductVariant #get_logical_product_variant(name: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProductVariant
Get details of a LogicalProductVariant.
626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 626 def get_logical_product_variant request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::GetLogicalProductVariantRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_logical_product_variant..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_logical_product_variant.timeout, metadata: , retry_policy: @config.rpcs.get_logical_product_variant.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @cloud_product_registry_read_service_stub.call_rpc :get_logical_product_variant, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_product_suite(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::ProductSuite #get_product_suite(name: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::ProductSuite
Get details of a ProductSuite.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 267 def get_product_suite request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::GetProductSuiteRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_product_suite..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_product_suite.timeout, metadata: , retry_policy: @config.rpcs.get_product_suite.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @cloud_product_registry_read_service_stub.call_rpc :get_product_suite, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_logical_product_variants(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProductVariant> #list_logical_product_variants(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProductVariant>
Lists LogicalProductVariants matching given criteria.
729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 729 def list_logical_product_variants request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::ListLogicalProductVariantsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_logical_product_variants..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_logical_product_variants.timeout, metadata: , retry_policy: @config.rpcs.list_logical_product_variants.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @cloud_product_registry_read_service_stub.call_rpc :list_logical_product_variants, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @cloud_product_registry_read_service_stub, :list_logical_product_variants, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_logical_products(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProduct> #list_logical_products(filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::LogicalProduct>
Lists LogicalProducts matching given criteria.
546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 546 def list_logical_products request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::ListLogicalProductsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_logical_products..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_logical_products.timeout, metadata: , retry_policy: @config.rpcs.list_logical_products.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @cloud_product_registry_read_service_stub.call_rpc :list_logical_products, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @cloud_product_registry_read_service_stub, :list_logical_products, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_product_suites(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::ProductSuite> #list_product_suites(page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ProductRegistry::V1::ProductSuite>
Lists ProductSuites.
364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 364 def list_product_suites request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::ListProductSuitesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_product_suites..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_product_suites.timeout, metadata: , retry_policy: @config.rpcs.list_product_suites.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @cloud_product_registry_read_service_stub.call_rpc :list_product_suites, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @cloud_product_registry_read_service_stub, :list_product_suites, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
216 217 218 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 216 def logger @cloud_product_registry_read_service_stub.logger end |
#lookup_entity(request, options = nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LookupEntityResponse #lookup_entity(lookup_uri: nil) ⇒ ::Google::Cloud::ProductRegistry::V1::LookupEntityResponse
Look up entities.
820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 820 def lookup_entity request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ProductRegistry::V1::LookupEntityRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.lookup_entity..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ProductRegistry::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.lookup_uri header_params["lookup_uri"] = request.lookup_uri end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.lookup_entity.timeout, metadata: , retry_policy: @config.rpcs.lookup_entity.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @cloud_product_registry_read_service_stub.call_rpc :lookup_entity, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
140 141 142 |
# File 'lib/google/cloud/product_registry/v1/cloud_product_registry_read_service/client.rb', line 140 def universe_domain @cloud_product_registry_read_service_stub.universe_domain end |