Class: Google::Cloud::ProductRegistry::V1::ListLogicalProductVariantsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ProductRegistry::V1::ListLogicalProductVariantsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb
Overview
Request message for ListLogicalProductVariants.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. The maximum number of logical product variants to return. The service may return fewer than this value. If unspecified, at most 100 logical product variants will be returned. The maximum value is 500; values above 500 will be coerced to 500.
142 143 144 145 |
# File 'proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb', line 142 class ListLogicalProductVariantsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous
ListLogicalProductVariants call. Provide this to retrieve the subsequent
page.
When paginating, all other parameters provided to
ListLogicalProductVariants must match the call that provided the page
token.
142 143 144 145 |
# File 'proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb', line 142 class ListLogicalProductVariantsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent logical product id. Format: logicalProducts/{logical_product}.
142 143 144 145 |
# File 'proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb', line 142 class ListLogicalProductVariantsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |