Class: Google::Cloud::ProductRegistry::V1::LogicalProduct
- Inherits:
-
Object
- Object
- Google::Cloud::ProductRegistry::V1::LogicalProduct
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/productregistry/v1/logical_product.rb
Overview
Represents an independent service offering that can be provisioned by a customer.
Instance Attribute Summary collapse
-
#lifecycle_state ⇒ ::Google::Cloud::ProductRegistry::V1::LifecycleState
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#product_suite ⇒ ::String
Product suite associated with the logical product.
-
#replaced ⇒ ::Boolean
readonly
Output only.
-
#replacement ⇒ ::String
readonly
Output only.
-
#title ⇒ ::String
Display name of the LogicalProduct.
-
#variants ⇒ ::Array<::String>
readonly
Output only.
Instance Attribute Details
#lifecycle_state ⇒ ::Google::Cloud::ProductRegistry::V1::LifecycleState (readonly)
Returns Output only. Current Lifecycle state of the logical product.
57 58 59 60 |
# File 'proto_docs/google/cloud/productregistry/v1/logical_product.rb', line 57 class LogicalProduct include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the LogicalProduct. Format: logicalProducts/{logical_product}.
57 58 59 60 |
# File 'proto_docs/google/cloud/productregistry/v1/logical_product.rb', line 57 class LogicalProduct include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#product_suite ⇒ ::String
Returns Product suite associated with the logical product. Format: productSuites/{product_suite}.
57 58 59 60 |
# File 'proto_docs/google/cloud/productregistry/v1/logical_product.rb', line 57 class LogicalProduct include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#replaced ⇒ ::Boolean (readonly)
Returns Output only. Indicates whether the logical product has been replaced. If
false, the product is active. If true, the product has been replaced by
another type, and the replacement field contains the resource name of
that replacement.
57 58 59 60 |
# File 'proto_docs/google/cloud/productregistry/v1/logical_product.rb', line 57 class LogicalProduct include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#replacement ⇒ ::String (readonly)
Returns Output only. The resource name of the Logical Entity that the logical product is replaced by. This field is only populated when this logical product is replaced by some other type. Eg: logicalProducts/{logical_product}/variants/{variant}, productSuites/{product_suite}, etc.
57 58 59 60 |
# File 'proto_docs/google/cloud/productregistry/v1/logical_product.rb', line 57 class LogicalProduct include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#title ⇒ ::String
Returns Display name of the LogicalProduct.
57 58 59 60 |
# File 'proto_docs/google/cloud/productregistry/v1/logical_product.rb', line 57 class LogicalProduct include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#variants ⇒ ::Array<::String> (readonly)
Returns Output only. Child variant resource references. Format: logicalProducts/{logical_product}/variants/{variant}.
57 58 59 60 |
# File 'proto_docs/google/cloud/productregistry/v1/logical_product.rb', line 57 class LogicalProduct include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |