Class: Google::Cloud::ProductRegistry::V1::LookupEntityResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ProductRegistry::V1::LookupEntityResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb
Overview
Response message for LookupEntity.
Instance Attribute Summary collapse
-
#logical_product ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProduct
Matched LogicalProduct.
-
#logical_product_variant ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProductVariant
Matched LogicalProductVariant.
-
#product_suite ⇒ ::Google::Cloud::ProductRegistry::V1::ProductSuite
Matched ProductSuite.
Instance Attribute Details
#logical_product ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProduct
Returns Matched LogicalProduct.
Note: The following fields are mutually exclusive: logical_product, logical_product_variant, product_suite. If a field in that set is populated, all other fields in the set will automatically be cleared.
189 190 191 192 |
# File 'proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb', line 189 class LookupEntityResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#logical_product_variant ⇒ ::Google::Cloud::ProductRegistry::V1::LogicalProductVariant
Returns Matched LogicalProductVariant.
Note: The following fields are mutually exclusive: logical_product_variant, logical_product, product_suite. If a field in that set is populated, all other fields in the set will automatically be cleared.
189 190 191 192 |
# File 'proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb', line 189 class LookupEntityResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#product_suite ⇒ ::Google::Cloud::ProductRegistry::V1::ProductSuite
Returns Matched ProductSuite.
Note: The following fields are mutually exclusive: product_suite, logical_product, logical_product_variant. If a field in that set is populated, all other fields in the set will automatically be cleared.
189 190 191 192 |
# File 'proto_docs/google/cloud/productregistry/v1/cloud_product_registry_read_service.rb', line 189 class LookupEntityResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |