Class: Google::Cloud::ProductRegistry::V1::ProductSuite
- Inherits:
-
Object
- Object
- Google::Cloud::ProductRegistry::V1::ProductSuite
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/productregistry/v1/product_suite.rb
Overview
Represents a unified grouping of products sharing a common brand and market positioning.
Instance Attribute Summary collapse
-
#logical_products ⇒ ::Array<::String>
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#replaced ⇒ ::Boolean
readonly
Output only.
-
#replacement ⇒ ::String
readonly
Output only.
-
#title ⇒ ::String
Title of the ProductSuite.
Instance Attribute Details
#logical_products ⇒ ::Array<::String> (readonly)
Returns Output only. LogicalProducts under this suite. Format: logicalProducts/{logical_product}.
49 50 51 52 |
# File 'proto_docs/google/cloud/productregistry/v1/product_suite.rb', line 49 class ProductSuite include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the ProductSuite. Format: productSuites/{product_suite}.
49 50 51 52 |
# File 'proto_docs/google/cloud/productregistry/v1/product_suite.rb', line 49 class ProductSuite include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#replaced ⇒ ::Boolean (readonly)
Returns Output only. Indicates whether the product suite has been replaced. If
false, the product suite is active. If true, the product suite has been
replaced by another type, and the replacement field contains the resource
name of that replacement.
49 50 51 52 |
# File 'proto_docs/google/cloud/productregistry/v1/product_suite.rb', line 49 class ProductSuite include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#replacement ⇒ ::String (readonly)
Returns Output only. The resource name of the Logical Entity that the product suite is replaced by. This field is only populated when this product suite is replaced by some other type. Eg: logicalProducts/{logical_product}, logicalProducts/{logical_product}/variants/{variant}, etc.
49 50 51 52 |
# File 'proto_docs/google/cloud/productregistry/v1/product_suite.rb', line 49 class ProductSuite include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#title ⇒ ::String
Returns Title of the ProductSuite.
49 50 51 52 |
# File 'proto_docs/google/cloud/productregistry/v1/product_suite.rb', line 49 class ProductSuite include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |